@@ -5,6 +5,7 @@ import (
 	"strconv"
 
 	"github.com/go-errors/errors"
+	"github.com/jesseduffield/lazygit/pkg/config"
 	"github.com/jesseduffield/lazygit/pkg/utils"
 )
 
@@ -58,5 +59,15 @@ func (self *FileCommands) GetEditCmdStr(filename string, lineNumber int) (string
 	}
 
 	editCmdTemplate := self.UserConfig.OS.EditCommandTemplate
+	if editCmdTemplate == config.DefaultEditCommandTemplate {
+		switch editor {
+		case "emacs", "nano", "vi", "vim":
+			editCmdTemplate = "{{editor}} +{{line}} {{filename}}"
+		case "subl":
+			editCmdTemplate = "{{editor}} {{filename}}:{{line}}"
+		case "code":
+			editCmdTemplate = "{{editor}} -r --goto {{filename}}:{{line}}"
+		}
+	}
 	return utils.ResolvePlaceholderString(editCmdTemplate, templateValues), nil
 }
