@@ -4,44 +4,30 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"strings"
 	"time"
 
 	"github.com/go-errors/errors"
 	"github.com/jesseduffield/lazygit/pkg/commands/loaders"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/commands/oscommands"
-	"github.com/jesseduffield/lazygit/pkg/common"
-	"github.com/jesseduffield/lazygit/pkg/gui/filetree"
 	"github.com/jesseduffield/lazygit/pkg/utils"
 )
 
 type WorkingTreeCommands struct {
-	*common.Common
-
-	cmd        oscommands.ICmdObjBuilder
-	os         WorkingTreeOSCommand
+	*GitCommon
 	submodule  *SubmoduleCommands
 	fileLoader *loaders.FileLoader
 }
 
-type WorkingTreeOSCommand interface {
-	RemoveFile(string) error
-	CreateFileWithContent(string, string) error
-	AppendLineToFile(string, string) error
-}
-
 func NewWorkingTreeCommands(
-	common *common.Common,
-	cmd oscommands.ICmdObjBuilder,
-	submoduleCommands *SubmoduleCommands,
-	osCommand WorkingTreeOSCommand,
+	gitCommon *GitCommon,
+	submodule *SubmoduleCommands,
 	fileLoader *loaders.FileLoader,
 ) *WorkingTreeCommands {
 	return &WorkingTreeCommands{
-		Common:     common,
-		cmd:        cmd,
-		os:         osCommand,
-		submodule:  submoduleCommands,
+		GitCommon:  gitCommon,
+		submodule:  submodule,
 		fileLoader: fileLoader,
 	}
 }
@@ -55,8 +41,16 @@ func (self *WorkingTreeCommands) OpenMergeTool() error {
 }
 
 // StageFile stages a file
-func (self *WorkingTreeCommands) StageFile(fileName string) error {
-	return self.cmd.New("git add -- " + self.cmd.Quote(fileName)).Run()
+func (self *WorkingTreeCommands) StageFile(path string) error {
+	return self.StageFiles([]string{path})
+}
+
+func (self *WorkingTreeCommands) StageFiles(paths []string) error {
+	quotedPaths := make([]string, len(paths))
+	for i, path := range paths {
+		quotedPaths[i] = self.cmd.Quote(path)
+	}
+	return self.cmd.New(fmt.Sprintf("git add -- %s", strings.Join(quotedPaths, " "))).Run()
 }
 
 // StageAll stages all files
@@ -174,12 +168,18 @@ func (self *WorkingTreeCommands) DiscardAllFileChanges(file *models.File) error
 	return self.DiscardUnstagedFileChanges(file)
 }
 
-func (self *WorkingTreeCommands) DiscardAllDirChanges(node *filetree.FileNode) error {
+type IFileNode interface {
+	ForEachFile(cb func(*models.File) error) error
+	GetFilePathsMatching(test func(*models.File) bool) []string
+	GetPath() string
+}
+
+func (self *WorkingTreeCommands) DiscardAllDirChanges(node IFileNode) error {
 	// this could be more efficient but we would need to handle all the edge cases
 	return node.ForEachFile(self.DiscardAllFileChanges)
 }
 
-func (self *WorkingTreeCommands) DiscardUnstagedDirChanges(node *filetree.FileNode) error {
+func (self *WorkingTreeCommands) DiscardUnstagedDirChanges(node IFileNode) error {
 	if err := self.RemoveUntrackedDirFiles(node); err != nil {
 		return err
 	}
@@ -192,9 +192,9 @@ func (self *WorkingTreeCommands) DiscardUnstagedDirChanges(node *filetree.FileNo
 	return nil
 }
 
-func (self *WorkingTreeCommands) RemoveUntrackedDirFiles(node *filetree.FileNode) error {
-	untrackedFilePaths := node.GetPathsMatching(
-		func(n *filetree.FileNode) bool { return n.File != nil && !n.File.GetIsTracked() },
+func (self *WorkingTreeCommands) RemoveUntrackedDirFiles(node IFileNode) error {
+	untrackedFilePaths := node.GetFilePathsMatching(
+		func(file *models.File) bool { return !file.GetIsTracked() },
 	)
 
 	for _, path := range untrackedFilePaths {
