@@ -6,6 +6,7 @@ var defaultUrlRegexStrings = []string{
 	`^(?:https?|ssh)://.*/(?P<owner>.*)/(?P<repo>.*?)(?:\.git)?$`,
 	`^git@.*:(?P<owner>.*)/(?P<repo>.*?)(?:\.git)?$`,
 }
+var defaultRepoURLTemplate = "https://{{.webDomain}}/{{.owner}}/{{.repo}}"
 
 // we've got less type safety using go templates but this lends itself better to
 // users adding custom service definitions in their config
@@ -15,6 +16,7 @@ var githubServiceDef = ServiceDefinition{
 	pullRequestURLIntoTargetBranch:  "/compare/{{.To}}...{{.From}}?expand=1",
 	commitURL:                       "/commit/{{.CommitSha}}",
 	regexStrings:                    defaultUrlRegexStrings,
+	repoURLTemplate:                 defaultRepoURLTemplate,
 }
 
 var bitbucketServiceDef = ServiceDefinition{
@@ -23,6 +25,7 @@ var bitbucketServiceDef = ServiceDefinition{
 	pullRequestURLIntoTargetBranch:  "/pull-requests/new?source={{.From}}&dest={{.To}}&t=1",
 	commitURL:                       "/commits/{{.CommitSha}}",
 	regexStrings:                    defaultUrlRegexStrings,
+	repoURLTemplate:                 defaultRepoURLTemplate,
 }
 
 var gitLabServiceDef = ServiceDefinition{
@@ -31,9 +34,27 @@ var gitLabServiceDef = ServiceDefinition{
 	pullRequestURLIntoTargetBranch:  "/merge_requests/new?merge_request[source_branch]={{.From}}&merge_request[target_branch]={{.To}}",
 	commitURL:                       "/commit/{{.CommitSha}}",
 	regexStrings:                    defaultUrlRegexStrings,
+	repoURLTemplate:                 defaultRepoURLTemplate,
 }
 
-var serviceDefinitions = []ServiceDefinition{githubServiceDef, bitbucketServiceDef, gitLabServiceDef}
+var azdoServiceDef = ServiceDefinition{
+	provider:                        "azuredevops",
+	pullRequestURLIntoDefaultBranch: "/pullrequestcreate?sourceRef={{.From}}",
+	pullRequestURLIntoTargetBranch:  "/pullrequestcreate?sourceRef={{.From}}&targetRef={{.To}}",
+	commitURL:                       "/commit/{{.CommitSha}}",
+	regexStrings: []string{
+		`^git@ssh.dev.azure.com.*/(?P<org>.*)/(?P<project>.*)/(?P<repo>.*?)(?:\.git)?$`,
+		`^https://.*@dev.azure.com/(?P<org>.*?)/(?P<project>.*?)/_git/(?P<repo>.*?)(?:\.git)?$`,
+	},
+	repoURLTemplate: "https://{{.webDomain}}/{{.org}}/{{.project}}/_git/{{.repo}}",
+}
+
+var serviceDefinitions = []ServiceDefinition{
+	githubServiceDef,
+	bitbucketServiceDef,
+	gitLabServiceDef,
+	azdoServiceDef,
+}
 
 var defaultServiceDomains = []ServiceDomain{
 	{
@@ -51,4 +72,9 @@ var defaultServiceDomains = []ServiceDomain{
 		gitDomain:         "gitlab.com",
 		webDomain:         "gitlab.com",
 	},
+	{
+		serviceDefinition: azdoServiceDef,
+		gitDomain:         "dev.azure.com",
+		webDomain:         "dev.azure.com",
+	},
 }
