@@ -3,11 +3,13 @@
 
 package config
 
+const DefaultEditCommandTemplate = `{{editor}} {{filename}}`
+
 // GetPlatformDefaultConfig gets the defaults for the platform
 func GetPlatformDefaultConfig() OSConfig {
 	return OSConfig{
 		EditCommand:         ``,
-		EditCommandTemplate: `{{editor}} {{filename}}`,
+		EditCommandTemplate: DefaultEditCommandTemplate,
 		OpenCommand:         "open {{filename}}",
 		OpenLinkCommand:     "open {{link}}",
 	}
