@@ -1,10 +1,12 @@
 package config
 
+const DefaultEditCommandTemplate = `{{editor}} {{filename}}`
+
 // GetPlatformDefaultConfig gets the defaults for the platform
 func GetPlatformDefaultConfig() OSConfig {
 	return OSConfig{
 		EditCommand:         ``,
-		EditCommandTemplate: `{{editor}} {{filename}}`,
+		EditCommandTemplate: DefaultEditCommandTemplate,
 		OpenCommand:         `xdg-open {{filename}} >/dev/null`,
 		OpenLinkCommand:     `xdg-open {{link}} >/dev/null`,
 	}
