@@ -11,11 +11,12 @@ type UserConfig struct {
 	QuitOnTopLevelReturn bool             `yaml:"quitOnTopLevelReturn"`
 	Keybinding           KeybindingConfig `yaml:"keybinding"`
 	// OS determines what defaults are set for opening files and links
-	OS                   OSConfig          `yaml:"os,omitempty"`
-	DisableStartupPopups bool              `yaml:"disableStartupPopups"`
-	CustomCommands       []CustomCommand   `yaml:"customCommands"`
-	Services             map[string]string `yaml:"services"`
-	NotARepository       string            `yaml:"notARepository"`
+	OS                           OSConfig          `yaml:"os,omitempty"`
+	DisableStartupPopups         bool              `yaml:"disableStartupPopups"`
+	CustomCommands               []CustomCommand   `yaml:"customCommands"`
+	Services                     map[string]string `yaml:"services"`
+	NotARepository               string            `yaml:"notARepository"`
+	PromptToReturnFromSubprocess bool              `yaml:"promptToReturnFromSubprocess"`
 }
 
 type RefresherConfig struct {
@@ -54,6 +55,7 @@ type ThemeConfig struct {
 	SelectedRangeBgColor      []string `yaml:"selectedRangeBgColor"`
 	CherryPickedCommitBgColor []string `yaml:"cherryPickedCommitBgColor"`
 	CherryPickedCommitFgColor []string `yaml:"cherryPickedCommitFgColor"`
+	UnstagedChangesColor      []string `yaml:"unstagedChangesColor"`
 }
 
 type CommitLengthConfig struct {
@@ -342,6 +344,7 @@ func GetDefaultConfig() *UserConfig {
 				SelectedRangeBgColor:      []string{"blue"},
 				CherryPickedCommitBgColor: []string{"blue"},
 				CherryPickedCommitFgColor: []string{"cyan"},
+				UnstagedChangesColor:      []string{"red"},
 			},
 			CommitLength:             CommitLengthConfig{Show: true},
 			SkipNoStagedFilesWarning: false,
@@ -533,10 +536,11 @@ func GetDefaultConfig() *UserConfig {
 				BulkMenu: "b",
 			},
 		},
-		OS:                   GetPlatformDefaultConfig(),
-		DisableStartupPopups: false,
-		CustomCommands:       []CustomCommand(nil),
-		Services:             map[string]string(nil),
-		NotARepository:       "prompt",
+		OS:                           GetPlatformDefaultConfig(),
+		DisableStartupPopups:         false,
+		CustomCommands:               []CustomCommand(nil),
+		Services:                     map[string]string(nil),
+		NotARepository:               "prompt",
+		PromptToReturnFromSubprocess: true,
 	}
 }
