@@ -121,7 +121,7 @@ func (gui *Gui) refreshCommitsWithLimit() error {
 			Limit:                gui.State.Panels.Commits.LimitCommits,
 			FilterPath:           gui.State.Modes.Filtering.GetPath(),
 			IncludeRebaseCommits: true,
-			RefName:              "HEAD",
+			RefName:              gui.refForLog(),
 			All:                  gui.State.ShowWholeGitGraph,
 		},
 	)
@@ -133,6 +133,22 @@ func (gui *Gui) refreshCommitsWithLimit() error {
 	return gui.postRefreshUpdate(gui.State.Contexts.BranchCommits)
 }
 
+func (gui *Gui) refForLog() string {
+	bisectInfo := gui.Git.Bisect.GetInfo()
+	gui.State.BisectInfo = bisectInfo
+
+	if !bisectInfo.Started() {
+		return "HEAD"
+	}
+
+	// need to see if our bisect's current commit is reachable from our 'new' ref.
+	if bisectInfo.Bisecting() && !gui.Git.Bisect.ReachableFromStart(bisectInfo) {
+		return bisectInfo.GetNewSha()
+	}
+
+	return bisectInfo.GetStartSha()
+}
+
 func (gui *Gui) refreshRebaseCommits() error {
 	gui.Mutexes.BranchCommitsMutex.Lock()
 	defer gui.Mutexes.BranchCommitsMutex.Unlock()
@@ -458,17 +474,25 @@ func (gui *Gui) handleCommitRevert() error {
 	if ok, err := gui.validateNotInFilterMode(); err != nil || !ok {
 		return err
 	}
-
 	commit := gui.getSelectedLocalCommit()
-
 	if commit.IsMerge() {
 		return gui.createRevertMergeCommitMenu(commit)
 	} else {
-		gui.logAction(gui.Tr.Actions.RevertCommit)
-		if err := gui.Git.Commit.Revert(commit.Sha); err != nil {
-			return gui.surfaceError(err)
-		}
-		return gui.afterRevertCommit()
+		return gui.ask(askOpts{
+			title: gui.Tr.Actions.RevertCommit,
+			prompt: utils.ResolvePlaceholderString(
+				gui.Tr.ConfirmRevertCommit,
+				map[string]string{
+					"selectedCommit": commit.ShortSha(),
+				}),
+			handleConfirm: func() error {
+				gui.logAction(gui.Tr.Actions.RevertCommit)
+				if err := gui.Git.Commit.Revert(commit.Sha); err != nil {
+					return gui.surfaceError(err)
+				}
+				return gui.afterRevertCommit()
+			},
+		})
 	}
 }
 
