@@ -7,8 +7,11 @@ import (
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/gui/style"
 	"github.com/jesseduffield/lazygit/pkg/theme"
+	"github.com/jesseduffield/lazygit/pkg/utils"
 )
 
+var branchPrefixColorCache = make(map[string]style.TextStyle)
+
 func GetBranchListDisplayStrings(branches []*models.Branch, fullDescription bool, diffName string) [][]string {
 	lines := make([][]string, len(branches))
 
@@ -58,6 +61,10 @@ func getBranchDisplayStrings(b *models.Branch, fullDescription bool, diffed bool
 func GetBranchTextStyle(name string) style.TextStyle {
 	branchType := strings.Split(name, "/")[0]
 
+	if value, ok := branchPrefixColorCache[branchType]; ok {
+		return value
+	}
+
 	switch branchType {
 	case "feature":
 		return style.FgGreen
@@ -84,3 +91,7 @@ func ColoredBranchStatus(branch *models.Branch) string {
 func BranchStatus(branch *models.Branch) string {
 	return fmt.Sprintf("↑%s↓%s", branch.Pushables, branch.Pullables)
 }
+
+func SetCustomBranches(customBranchColors map[string]string) {
+	branchPrefixColorCache = utils.SetCustomColors(customBranchColors)
+}
