@@ -18,7 +18,7 @@ func dutchTranslationSet() TranslationSet {
 		CredentialsPassword:                 "Wachtwoord",
 		CredentialsPassphrase:               "Voer een wachtwoordzin in voor de SSH-sleutel",
 		PassUnameWrong:                      "Wachtwoord en/of gebruikersnaam verkeerd",
-		CommitChanges:                       "Commit veranderingen",
+		CommitChanges:                       "commit veranderingen",
 		AmendLastCommit:                     "wijzig laatste commit",
 		SureToAmend:                         "Weet je zeker dat je de laatste commit wilt wijzigen? U kunt het commit-bericht wijzigen vanuit het commits-paneel.",
 		NoCommitToAmend:                     "Er is geen commits om te wijzigen.",
@@ -241,7 +241,7 @@ func dutchTranslationSet() TranslationSet {
 		SureSquashAboveCommits:              `Weet je zeker dat je alles wil squash/fixup! voor de bovenstaand commits {{.commit}}?`,
 		CreateFixupCommit:                   `Creëer fixup commit`,
 		SureCreateFixupCommit:               `Weet je zeker dat je een fixup wil maken! commit voor commit {{.commit}}?`,
-		LcExecuteCustomCommand:              "voor aangepaste commando uit",
+		LcExecuteCustomCommand:              "voer aangepaste commando uit",
 		CustomCommand:                       "Aangepaste commando:",
 		LcCommitChangesWithoutHook:          "commit veranderingen zonder pre-commit hook",
 		SkipHookPrefixNotConfigured:         "Je hebt nog niet een commit bericht voorvoegsel ingesteld voor het overslaan van hooks. Set `git.skipHookPrefix = 'WIP'` in je config",
@@ -263,7 +263,7 @@ func dutchTranslationSet() TranslationSet {
 		LcEnterFile:                         "enter bestand om geselecteerde regels toe te voegen aan de patch",
 		ExitLineByLineMode:                  `sluit lijn-bij-lijn modus`,
 		EnterUpstream:                       `Enter upstream als '<remote> <branchnaam>'`,
-		ReturnToRemotesList:                 `Ga terug naar remotes lijst`,
+		ReturnToRemotesList:                 `ga terug naar remotes lijst`,
 		LcAddNewRemote:                      `voeg een nieuwe remote toe`,
 		LcNewRemoteName:                     `Nieuwe remote name:`,
 		LcNewRemoteUrl:                      `Nieuwe remote url:`,
